@@ -131,7 +131,7 @@ else{
 echo "</td></tr>";
 
 echo "<tr bgcolor='#D9DBED'><td>";
-echo "ƻ륵ФIP\n";
+echo "ƻ륵IP \n";
 echo "</td><td>";
 if(0 == strlen($CNAME)){ 
    echo "<INPUT type='text' NAME=SOCK_IPADDR size='24' value='$my_server_ip'>";
@@ -142,7 +142,7 @@ else{
 echo "</td></tr>";
 
 echo "<tr><td>";
-echo "ƻ륵ФΥݡȭ\n";
+echo "ƻ륵ФΥݡ\n";
 echo "</td><td>";
 if(0 == strlen($CNAME)){ 
    echo "<INPUT type='text' NAME=SOCK_PORT size='6' value='9988'>";
@@ -153,7 +153,7 @@ else{
 echo "</td></tr>";
 
 echo "<tr bgcolor='#D9DBED'><td>";
-echo "ƻ륵ФIP\n";
+echo "ƻ륵IP \n";
 echo "</td><td>";
 if(0 == strlen($CNAME)){ 
    echo "<INPUT type='text' NAME=SOCK2_IPADDR size='24' value='$my_server_ip'>";
@@ -164,7 +164,7 @@ else{
 echo "</td></tr>";
 
 echo "<tr><td>";
-echo "ƻ륵ФΥݡȭ\n";
+echo "ƻ륵ФΥݡ\n";
 echo "</td><td>";
 if(0 == strlen($CNAME)){ 
    echo "<INPUT type='text' NAME=SOCK2_PORT size='6' value='9988'>";
@@ -208,7 +208,7 @@ else{
 echo "</td></tr>";
 
 echo "<tr><td>";
-echo "ƻ륤󥿡Х뭡\n";
+echo "ƻ륤󥿡Х \n";
 echo "</td><td>";
 echo "<select size=1 name=BAT_INT>";
 if(0 == strlen($CNAME)){ 
@@ -265,6 +265,7 @@ echo "<option value=15>15";
 echo "<option value=20>20";
 echo "<option value=25>25";
 echo "<option value=30>30";
+echo "<option value=60>60";
 echo "</select>";
 echo "</td></tr>";
 
@@ -283,9 +284,9 @@ echo "<option value=2>2";
 echo "<option value=3>3";
 echo "<option value=4>4";
 echo "<option value=5>5";
-echo "<option value=6>6";
 echo "<option value=7>7";
-echo "<option value=8>8";
+echo "<option value=10>10";
+echo "<option value=15>15";
 echo "</select>";
 echo "</td></tr>";
 
