@@ -215,7 +215,7 @@ elseif(0 == strcmp($MONITOR, "COMAND")){
    echo "</font>";
    }
 
-elseif(0 == strcmp($MONITOR, "PORT") && 0 != strcmp($PROTO, "DHW")){
+elseif(0 == strcmp($MONITOR, "PORT") && 0 != strcmp($PROTO, "DHW") && 0 != strcmp($PROTO, "MYSQL")){
    echo "<table>";
    echo "<font color=red>";
    echo "<tr><td>ƻIPURL               </td><td>=   </td><td> $CINFO</td></tr>";
@@ -269,6 +269,36 @@ elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "DHW")){
    echo "</font>";
    }
 
+
+elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "MYSQL")){
+   echo "<table>";
+   echo "<font color=red>";
+   echo "<tr><td>MYSQL³                 </td><td>=   </td><td>$CINFO</td></tr>";
+   echo "<tr><td>ƻξ                  </td><td>=   </td><td>$PINFO</td></tr>";
+   echo "</font>";
+   echo "<tr><td>ƻ°                      </td><td>=   </td><td>$MONITOR</td></tr>";
+   echo "<tr><td>顼λUCT             </td><td>=   </td><td>$UCT</td></tr>"; print("\n");
+   echo "<tr><td>顼λlocal           </td><td>=   </td><td>$YE:$MO:$DA:$HA:$MI:$SE</td></tr>";
+   echo "<tr><td>ƻˡ                </td><td>=   </td><td>$SIGN</td></tr>";
+   echo "<tr><td>MYSQLƻδƻݡ         </td><td>=   </td><td>$PORT</td></tr>";
+   echo "<tr><td>¹Ԥ                  </td><td>=   </td><td>$WTIME</td></tr>";
+   echo "<tr><td>MYSQL꡼                 </td><td>=   </td><td>$COM</td></tr>";
+   echo "<tr><td>MYSQL顼ξܺ               </td><td>=   </td><td>$ERRDATA</td></tr>";
+   echo "<tr><td>δƻΥץ饤ƥ    </td><td>=   </td><td>$PRINO</td></tr>";
+   echo "<tr><td>ȣ                    </td><td>=   </td><td>$FREE1</td></tr>";
+   echo "<tr><td>ƻ륯饤IP            </td><td>=   </td><td>$CIP</td></tr>";
+   echo "<tr><td>ƻ륯饤̾            </td><td>=   </td><td>$CNAME</td><tr>";
+   echo "</table>";
+
+   echo "\n\n";
+   echo "<font color=red>";
+   echo "оݤƻ뤷Ƥ륯饤Ȥ $CNAME $CIP Ǥ"; print("\n");
+   echo "δƻܤϥ֥å̾ $FREE4 ˴ޤޤƤޤ"; print("\n");
+   echo "</font>";
+   }
+
+
+
 else{
    echo "<table>";
    echo "<font color=red>";
