@@ -187,12 +187,14 @@ if(0 == strcmp($MONITOR, "PORT")){
    echo "<option value=UDP>UDP";
    echo "<option value=TCP>TCP";
    echo "<option value=URL>URL";
+   echo "<option value=GET>GET";
    echo "<option value=SSL>SSL";
    echo "<option value=SMTP>SMTP";
    echo "<option value=FTP>FTP";
    echo "<option value=POP>POP";
    echo "<option value=SSH>SSH";
    echo "<option value=DHW>DHW";
+   echo "<option value=MYSQL>MYSQL";
    echo "<option value=SNTP>SNTP";
    echo "<option value=HOST>HOST";
    echo "<option value=NOT>NOT";
@@ -225,6 +227,13 @@ elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "DHW")){
    echo "<INPUT type='text' NAME=COM size='70' value='$COM'>";
    echo "</td></tr>";
    }
+elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "MYSQL")){
+   echo "<tr bgcolor='#D9DBED'><td>";
+   echo "MYSQLǤΥ꡼\n";
+   echo "</td><td>";
+   echo "<INPUT type='text' NAME=COM size='70' value='$COM'>";
+   echo "</td></tr>";
+   }
 
 elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "SSL")){
    if(0 == strcmp($COM, "NOT")){
