@@ -84,7 +84,7 @@ print("ƻ°<br>\n");
 print("</td>\n");
 print("<td>\n");
 print("<select size=1 name=MONITOR>\n");
-print("<option value=PORT>PORT or DHW\n");
+print("<option value=PORT>PORT or DHW or MYSQL\n");
 print("<option value=COMAND>COMAND\n");
 print("<option value=SNMP>SNMP\n");
 print("</select>\n");
