@@ -51,7 +51,7 @@ print("\n");
 print("\n");
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -113,13 +113,13 @@ $line = "+------------+";
 
 
 
-$result1 = pg_query($conn, "select distinct(cname) from monitor where cip='$cip';");
+$result1 = db_query($conn, "select distinct(cname) from monitor where cip='$cip';");
 
 if(!$result1){
    print("bud query\n");
    exit;
    }
-$num1 = pg_num_rows($result1);
+$num1 = db_num_rows($result1);
 if($num1 <= 0){
    print("(1)no data\n");
 // exit;
@@ -127,18 +127,18 @@ if($num1 <= 0){
 
 $s1 = 0;
 while($s1 < $num1){
-   $CNAME = enco_rtrim(pg_fetch_Result($result1, $s1, cname));
+   $CNAME = enco_rtrim(db_fetch_Result($result1, $s1, cname));
 
 
 
 
-   $result2 = pg_query($conn, "select distinct(free4) from monitor where cip='$cip' and cname='$CNAME';");
+   $result2 = db_query($conn, "select distinct(free4) from monitor where cip='$cip' and cname='$CNAME';");
 
    if(!$result2){
       print("bud query\n");
       exit;
       }
-   $num2 = pg_num_rows($result2);
+   $num2 = db_num_rows($result2);
    if($num2 <= 0){
       print("(1)no data\n");
 //    exit;
@@ -146,7 +146,7 @@ while($s1 < $num1){
 
    $s2 = 0;
    while($s2 < $num2){
-      $FREE4 = enco_rtrim(pg_fetch_Result($result2, $s2, free4));
+      $FREE4 = enco_rtrim(db_fetch_Result($result2, $s2, free4));
 
 
 
@@ -198,14 +198,14 @@ while($s1 < $num1){
 
 
 
-      $result3 = pg_query($conn,
+      $result3 = db_query($conn,
         "select come,monitor,proto,prino,com,port,uno from monitor where cip='$cip' and free4='$FREE4';");
 
       if(!$result3){
          print("bud query\n");
          exit;
          }
-      $num3 = pg_num_rows($result3);
+      $num3 = db_num_rows($result3);
  //   print("$num3 .");
       if($num3 <= 0){
          print("(1)no data\n");
@@ -214,13 +214,13 @@ while($s1 < $num1){
       $s3 = 0;
       while($s3 < $num3){
 
-         $COME = enco_rtrim(pg_fetch_Result($result3, $s3, come));
-         $MONITOR = enco_rtrim(pg_fetch_Result($result3, $s3, monitor));
-         $PROTO = enco_rtrim(pg_fetch_Result($result3, $s3, proto));
-         $COM = enco_rtrim(pg_fetch_Result($result3, $s3, com));
-         $PORT = enco_rtrim(pg_fetch_Result($result3, $s3, port));
-         $PRINO = enco_rtrim(pg_fetch_Result($result3, $s3, prino));
-         $UNO = enco_rtrim(pg_fetch_Result($result3, $s3, uno));
+         $COME = enco_rtrim(db_fetch_Result($result3, $s3, come));
+         $MONITOR = enco_rtrim(db_fetch_Result($result3, $s3, monitor));
+         $PROTO = enco_rtrim(db_fetch_Result($result3, $s3, proto));
+         $COM = enco_rtrim(db_fetch_Result($result3, $s3, com));
+         $PORT = enco_rtrim(db_fetch_Result($result3, $s3, port));
+         $PRINO = enco_rtrim(db_fetch_Result($result3, $s3, prino));
+         $UNO = enco_rtrim(db_fetch_Result($result3, $s3, uno));
 
          if($PRINO <= 1){
             $pcol = "bgcolor=red";
@@ -269,7 +269,7 @@ while($s1 < $num1){
          $s3++;
          }
 
-      pg_free_result($result3);
+      db_free_result($result3);
 
 
 
@@ -299,7 +299,7 @@ while($s1 < $num1){
 
       $s2++;
       }
-   pg_free_result($result2);
+   db_free_result($result2);
 
 
 
@@ -322,7 +322,7 @@ while($s1 < $num1){
 
    $s1++;
    }
-pg_free_result($result1);
+db_free_result($result1);
 
 
 
@@ -331,7 +331,7 @@ pg_free_result($result1);
 
 
 
-pg_Close($conn);
+db_Close($conn);
 
 
 
