@@ -109,6 +109,9 @@
 #define HTTPS_1 "SLL X509 Ǥ "
 #define HTTPS_2 "SLL X509 ϰ۾֤ƤޤΥǡǤ "
 
+#define MYSQL_1 "MYSQL ưǤ "
+#define MYSQL_2 "MYSQL ϰ۾֤ƤޤΥǡǤ "
+
 
 #define MONITOR_ERR_1  "ʤƻ°ꤷƤޤ㤨SNMPȤʤ饤ȤSNMP꤬Ƥޤ  "
 
@@ -129,6 +132,9 @@
 #define DHW_ERR3 "DHWϥ顼֤ޤǤ "
 #define DHW_ERR4 "DHW֤ͤ³ڤޤDHW˥ॢȤ⤷ޤ "
 
+#define DB_ERR1  "DB³ΥǥߥοǤ "
+#define DB_ERR2  "DB³Υǡ礭Ǥ "
+
 #endif
 
 
