@@ -17,7 +17,7 @@ extern struct scan_buf sb;
 int path_check(char *chA)
 {
 int bu;
-char ch[29][BUF_COM];
+char ch[31][BUF_COM];
 int count = 0;
 char * non = "NOT";
 char * sock_ipaddr="SOCK_IPADDR";
@@ -47,6 +47,8 @@ char * midump_filename_2 ="MIDUMP_FILE_2";
 char * mid_max ="MID_MAX";
 char * thread_len="THREAD_LEN";
 char * mid_int="MID_INT";
+char * dns_ip="DNS_IP";
+char * dns_ip2="DNS_IP2";
 
 self_memcpy(ch[0], non, BUF_COM);
 self_memcpy(ch[1], sock_ipaddr, BUF_COM);
@@ -76,10 +78,12 @@ self_memcpy(ch[24], mid_max, BUF_COM);
 self_memcpy(ch[25], thread_len, BUF_COM);
 self_memcpy(ch[26], mid_int, BUF_COM);
 self_memcpy(ch[27], midump_filename_2, BUF_COM);
+self_memcpy(ch[28], dns_ip, BUF_COM);
+self_memcpy(ch[29], dns_ip2, BUF_COM);
 
 bu = 0;
 if(BUF_COM > strlen(chA)){
-   for(count=1; count < 28; count++){
+   for(count=1; count < 30; count++){
       if(0 == memcmp(chA, ch[count], (int)strlen(ch[count])+1)){
          bu=count;
          }
