@@ -41,6 +41,9 @@ int optin(int, char *[]);
 int scan_malloc_set(private_data_t *);
 int scan_malloc_free(private_data_t *);
 int scan_malloc_null(private_data_t *);
+int db_malloc_null(private_data_t *);
+
+
 int m_exit(int);
 
 
@@ -60,8 +63,8 @@ int satmpnull(void);
 int satmpcalloc(void);
 
 /* --- scan_port.c --- */
-int scan_port(struct scan_buf *);
-
+int scan_port(private_data_t *pd);
+char * db_data_delim(char * backdata, char * db_data, private_data_t *pd, int * ret);
 
 /* --- scan_comand.c --- */
 int scan_comand(private_data_t *);
@@ -88,7 +91,3 @@ int ch_en(char);
 int cal4(int, int, char);
 
 
-
-
-
-
