@@ -1,10 +1,12 @@
 
-#include<arpa/inet.h>
-#include<netinet/in.h>
-
 #include<netdb.h>
 #include<stdio.h>
 #include<stdlib.h>
+#include<fcntl.h>
+#include<sys/socket.h>
+#include<netinet/in.h>
+#include <arpa/inet.h>
+
 
 #include"sitar_scan.h"
 
@@ -12,6 +14,7 @@
 int main(int argc, char * argv[])
 {
 struct sockaddr_in my_addr;
+char buff[256];
 
 if(argc != 2){
    fprintf(stderr,"resolv Ver1.0 resolv <URL>\n");
@@ -19,7 +22,8 @@ if(argc != 2){
    }
 
 my_addr.sin_addr.s_addr = resolve_name(argv[1]);
-printf("%s\n", inet_ntoa(my_addr.sin_addr));
+// printf("%s\n", inet_ntoa(my_addr.sin_addr));
+printf("%s\n", inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff)));
 
 return 0;
 }
