@@ -155,7 +155,7 @@ for(co = 0; co < gd.td.tbufmax; co++){
                   printf("MONITOR: %s: %s: %s: %s:\n",
                     pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                   #endif 
-                  scan_port(&pd->sb);
+                  scan_port(pd);
                   }
                else if(0 == self_memcmp(pd->sb.ch_tool, "COMAND")){
                   #ifdef MONITOR_BUG
