@@ -61,8 +61,7 @@ printf("DHW: scan_dhw_connect(1): DHW COMMAND %s\n", comand);
 
 if((sk = socket(AF_INET, SOCK_STREAM, 0))==-1){
    fprintf(stderr,"scan_dhw URL=%s Port=%d tcp %s", url_dom, port, SOCK_1);
-   backdata=safe_sprintf(backdata, BUF_MAX,
-    "URL=%s Port=%d tcp %s", url_dom, port, SOCK_1);
+   backdata=safe_sprintf(backdata, BUF_MAX, "DHW=%s Port=%d: %s", url_dom, port, SOCK_1);
    * pst = -1;
    return backdata;
    }
@@ -77,9 +76,9 @@ if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
    backdata = resolvename_th(backdata, url_dom, timeout, &resoip);
    }
 else{
-   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret, '4');
    if(resolv_ret < 0){
-      backdata = resolvename_sk(backdata, url_dom, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      backdata = resolvename_sk(backdata, url_dom, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret, '4');
       fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", url_dom, backdata);
       }
    }
@@ -87,8 +86,7 @@ else{
 my_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
-   backdata=safe_sprintf(backdata,BUF_MAX,"%s %s %d\n",
-    SOCK_2, url_dom, (int)my_addr.sin_addr.s_addr);
+   backdata = safe_sprintf(backdata,BUF_MAX,"%s %d: %s\n", SOCK_2, url_dom, (int)my_addr.sin_addr.s_addr, SOCK_2);
    close(sk);
    * pst = -1;
    return backdata;
@@ -106,10 +104,9 @@ re = connect(sk, (struct sockaddr *)(long int)&my_addr, sizeof(my_addr));
 
 if(re >= 0){
    fcntl(sk, F_SETFL, 0);
-   backdata=safe_sprintf(backdata,BUF_MAX,
-    "URL=%s Port=%d %s", url_dom, port, SOCK_5);
+   backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_5);
    #ifdef URL_BUG
-   printf("URL: scan_dhw_connect(4): CONNECT SUCCESS %s\n", backdata);
+   printf("URL: scan_dhw_connect(3): CONNECT SUCCESS %s\n", backdata);
    #endif
    goto notselect;
    }
@@ -124,10 +121,9 @@ if(errno == EINPROGRESS){
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
       // select異常終了
       if(retval < 0){
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SOCK_5);
+         backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_15);
          #ifdef DHW_BUG
-         printf("DHW: scan_dhw_connect(3): select err BREAK- %d - %s\n", retval, backdata);
+         printf("DHW: scan_dhw_connect(4): select err BREAK- %d - %s\n", retval, backdata);
          #endif
          // 非同期から同期通信へ
          fcntl(sk, F_SETFL, 0);
@@ -137,10 +133,9 @@ if(errno == EINPROGRESS){
          }
       // selectのタイムアウト
       else if(retval == 0){
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SOCK_5);
+         backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_16);
          #ifdef DHW_BUG
-         printf("DHW: scan_dhw_connect(4): select time out BREAK- %d - %s\n",
+         printf("DHW: scan_dhw_connect(5): select time out BREAK- %d - %s\n",
            retval, backdata);
          #endif
          // 非同期通信から同期通信へ
@@ -153,10 +148,9 @@ if(errno == EINPROGRESS){
       else{
          // 非同期通信から同期通信に
          fcntl(sk, F_SETFL, 0);
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s", url_dom, port, SOCK_3);
+         backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_3);
          #ifdef DHW_BUG
-         printf("DHW: scan_dhw_connect(5): select time succes BREAK- %d - %s\n", retval, backdata);
+         printf("DHW: scan_dhw_connect(6): select time succes BREAK- %d - %s\n", retval, backdata);
          #endif
          break;
          }
@@ -169,10 +163,9 @@ if(errno == EINPROGRESS){
 
    // socketに関するペンディングエラーを返す
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
-      backdata=safe_sprintf(backdata,BUF_MAX,
-       "URL=%s Port=%d %s", url_dom, port, SOCK_13);
+      backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_13);
       #ifdef DHW_BUG
-      fprintf(stderr,"getsockopt(6) Errors!\n");
+      fprintf(stderr,"getsockopt(7) Errors!\n");
       #endif
       close(sk);
       * pst = -1;
@@ -182,10 +175,9 @@ if(errno == EINPROGRESS){
    else{
       // エラーがある
       if(retval){
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s: TCP %s", url_dom, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
+         backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s: %s", url_dom, ip_addr, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
          #ifdef DHW_BUG
-         printf("DHW: scan_dhw_connect(7): 1 SO_ERROR %d -%s\n", retval, backdata);
+         printf("DHW: scan_dhw_connect(8): 1 SO_ERROR %d -%s\n", retval, backdata);
          #endif
          close(sk);
          * pst = -1;
@@ -194,10 +186,9 @@ if(errno == EINPROGRESS){
 
       // エラーがない
       else{
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s", url_dom, port, SOCK_3);
+         backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_3);
          #ifdef DHW_BUG
-         printf("DHW: scan_dhw_connect(8): 1 SO_ERROR else %d -%s\n", retval, backdata);
+         printf("DHW: scan_dhw_connect(9): 1 SO_ERROR else %d -%s\n", retval, backdata);
          #endif
 
          if((strlen(comand) + 5) < BUF_LEN){
@@ -208,7 +199,7 @@ if(errno == EINPROGRESS){
             }
 
          #ifdef DHW_BUG
-         printf("DHW: scan_dhw_connect(9): set_request*send-- %s --\n", senddata);
+         printf("DHW: scan_dhw_connect(10): set_request*send-- %s --\n", senddata);
          #endif 
 
          // 非同期通信の開始
@@ -227,24 +218,22 @@ if(errno == EINPROGRESS){
             // select の異常終了
             if(retval < 0){
                #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(10): retval 0 ERR\n");
+               printf("DHW: scan_dhw_connect(11): retval 0 ERR\n");
                #endif 
-               backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, URL_2);
+               backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_15);
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
                return backdata;
                }
-
             // selectのタイムアウト
             else if(retval == 0){
                #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(11): retval 1 ERR\n"); 
+               printf("DHW: scan_dhw_connect(12): retval 1 ERR\n"); 
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s" , url_dom, port, SOCK_16, URL_3);
+                "DHW=%s IP=%s Port=%d: %s" , url_dom, ip_addr, port, SOCK_16);
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
                close(sk);
@@ -254,59 +243,110 @@ if(errno == EINPROGRESS){
 
             // select 正常
             else{
+               // 非同期通信から同期通信に戻す
+               fcntl(sk, F_SETFL, 0);
 //             dcount = recv(sk, recvdata, BUF_LEN, 0);
-               dcount = socket_reada(sk, recvdata, BUF_LEN);
+               dcount = socket_readas(sk, recvdata, BUF_LEN, timeout, 0);
+
+               swap_mem(recvdata, '\t', ' ');
+               swap_mem(recvdata, ',', ' ');
+               swap_mem(recvdata, '"', ' ');
+
                #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(12): recv-- %s --\n", recvdata);
+               printf("DHW: scan_dhw_connect(13): recv-- %s --\n", recvdata);
                #endif
 
-// printf("dcount=%d  tcount=%d\n", dcount, 1 + (mem_tcount(recvdata, '\n')));
-
-               // 受信量がゼロ、エラーではない場合
+               // 受信量がゼロ
                if(dcount < 1){
-                  backdata = safe_sprintf(backdata,BUF_MAX,
-                    "DHW COMMAND SUCCESS %s" , comand);
-                  ret = 0;
+                  ret = -1;
+                  backdata = safe_sprintf(backdata,BUF_MAX, "%s", DHW_ERR4);
                   #ifdef DHW_BUG
-                  printf("DHW: scan_dhw_connect(13): <%d>\n", ret);
+                  printf("DHW: scan_dhw_connect(14): <%s> %d\n", backdata, ret);
                   #endif
                   }
 
-
                // 何らかのエラーを取得した場合
                else{
-                  if(0 == memcmp(recvdata, "###DHWINFO ", 11)){                  
-                     if(dcount == 1 + (mem_tcount(recvdata, '\n'))){
+                  // 先頭が###DHWINFOな場合
+                  if(0 == memcmp(recvdata, "###DHWINFO ", 11)){ 
+                     int an;
+                     an = 1 + (mem_tcount(recvdata, '\n'));
+                     // 改行までのサイズと受信サイズが等しいので正常終了
+                     if(dcount == an){
+                        backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR3);
+                        rm_char(backdata, '\n');
                         ret = 0;
-                        }
-                     else{
-
-
-                        ret = -1;
                         #ifdef DHW_BUG
-                        printf("DHW: scan_dhw_connect(14): <%d><2> %s\n", ret, backdata);
+                        printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
+                          recvdata, dcount, an);
                         #endif
                         }
+                     // 改行のあとにまだある場合
+                     else{
+                        if(0 == memcmp(recvdata + an, "###DHWINFO ", 11)){ 
+                           int in;
+                           in = 1 + (char_point(recvdata, '\n', 2));
+                           // 改行までのサイズと受信サイズが等しいので正常終了
+                           if(dcount == in){
+                              backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR3);
+                              rm_char(backdata, '\n');
+                              ret = 0;
+                              #ifdef DHW_BUG
+                              printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
+                                recvdata, dcount, in);
+                              #endif
+                              }
+                           else{
+                              backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + in, DHW_ERR1);
+                              rm_char(backdata, '\n');
+                              ret = -1;
+                              #ifdef DHW_BUG
+                              printf("DHW: scan_dhw_connect(15): <%d> %s\n", ret, backdata);
+                              #endif
+                              }
+                           }
+                        else{
+                           backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + an, DHW_ERR1);
+                           rm_char(backdata, '\n');
+                           ret = -1;
+                           #ifdef DHW_BUG
+                           printf("DHW: scan_dhw_connect(16): <%d> %s\n", ret, backdata);
+                           #endif
+                           }
+                        }
+                     }
+
+                  // 先頭が###DHWINFOでないのでダメ
+                  else{
+                     int an;
+                     an = 1 + (mem_tcount(recvdata, '\n'));
+
+                     if(dcount == an){
+                        backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR2);
+                        rm_char(backdata, '\n');
+                        ret = -1;
+                        printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
+                          recvdata, dcount, 1 + (mem_tcount(recvdata, '\n')));
+                        }
+                     else{
+                        backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + an, DHW_ERR2);
+                        rm_char(backdata, '\n');
+                        ret = -1;
+                        #ifdef DHW_BUG
+                        printf("DHW: scan_dhw_connect(17): <%d> %s\n", ret, backdata);
+                        #endif
+                        }
+
                      }
-                  else{
-                     ret = -1;
-                     #ifdef DHW_BUG
-                     printf("DHW: scan_dhw_connect(14-2): <%d><2> %s\n", ret, backdata);
-                     #endif
-                     }
-                  }
 
-               if(ret == -1){
-                  swap_mem(recvdata, ',', ' ');
-                  backdata=safe_memcpy(backdata, recvdata, BUF_LEN);
                   }
 
                #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(15): %d <2> %s\n", ret, backdata);
+               printf("DHW: scan_dhw_connect(18): %d <2> %s\n", ret, backdata);
                #endif
 
                // 非同期通信から同期通信に戻す
-               fcntl(sk, F_SETFL, 0);
+           //  fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = ret;
                return backdata;
@@ -327,10 +367,9 @@ if(errno == EINPROGRESS){
 
 // 非同期通信から同期通信
 fcntl(sk, F_SETFL, 0);
-backdata=safe_sprintf(backdata,BUF_MAX,
- "URL=%s Port=%d %s", url_dom, port, SOCK_14);
+backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_14);
 #ifdef DHW_BUG
-printf("DHW: scan_dhw_connect(16): not connection last out\n");
+printf("DHW: scan_dhw_connect(19): not connection last out\n");
 #endif
 
 close(sk);
