@@ -119,7 +119,7 @@ if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
    backdata = resolvename_th(backdata, url_dom, timeout, &resoip);
    }
 else{
-   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret, '4');
    }
 
 my_addr.sin_addr.s_addr = resoip;
@@ -148,7 +148,7 @@ if(re >= 0){
   // 非同期通信から同期通信に
    fcntl(sk, F_SETFL, 0);
    backdata=safe_sprintf(backdata,BUF_MAX,
-    "SMTP=%s Port=%d %s", url_dom, port, SOCK_5);
+    "SMTP=%s IP=%s Port=%d %s", url_dom, ip_addr, port, SOCK_5);
    #ifdef SMTP_BUG
    printf("SMTP: scan_url_connect(1): CONNECT SUCCESS %s\n", backdata);
    #endif
@@ -169,7 +169,7 @@ if(errno == EINPROGRESS){
          printf("SMTP: scan_smtp_connect(2): select error BREAK- %d -\n", retval);
          #endif
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SOCK_5);
+          "SMTP=%s IP=%s Port=%d %s %s", url_dom, ip_addr, port, SOCK_15, SOCK_5);
          // 非同期通信から同期通信に
          fcntl(sk, F_SETFL, 0);
          close(sk);
@@ -181,7 +181,7 @@ if(errno == EINPROGRESS){
          printf("SMTP: scan_smtp_connect(3): select timed out BREAK- %d -\n", retval);
          #endif
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SOCK_5);
+          "SMTP=%s IP=%s Port=%d %s %s", url_dom, ip_addr, port, SOCK_16, SOCK_5);
          // 非同期から同期に
          fcntl(sk, F_SETFL, 0);
          close(sk);
@@ -196,7 +196,7 @@ if(errno == EINPROGRESS){
          printf("SMTP: scan_smtp_connect(4): select time succes BREAK- %d -\n", retval);
          #endif
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s", url_dom, port, SOCK_3);
+          "SMTP=%s IP=%s Port=%d %s", url_dom, ip_addr, port, SOCK_3);
          break;
          }
       }
@@ -210,7 +210,7 @@ if(errno == EINPROGRESS){
    // ソケットに関するペンディングエラーを戻す
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
       backdata=safe_sprintf(backdata,BUF_MAX,
-       "URL=%s Port=%d %s", url_dom, port, SOCK_13);
+       "SMTP=%s IP=%s Port=%d %s", url_dom, ip_addr, port, SOCK_13);
       #ifdef SMTP_BUG
       fprintf(stderr,"getsockopt(5) Errors!\n");
       #endif
@@ -225,7 +225,7 @@ if(errno == EINPROGRESS){
          printf("SMTP: scan_smtp_connect(6): 1 SO_ERROR %d -\n", retval);
          #endif
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d Error! %s", url_dom, port, SOCK_5);
+          "SMTP=%s IP=%s Port=%d Error! %s", url_dom, ip_addr, port, SOCK_5);
          close(sk);
          * pst = -1;
          return backdata;
@@ -249,7 +249,7 @@ if(errno == EINPROGRESS){
                printf("SMTP: scan_smtp_connect(7): retval 0 ERR ===\n");
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SMTP_22);
+                "(1)SMTP=%s IP=%s Port=%d %s %s", url_dom, ip_addr, port, SOCK_15, SMTP_22);
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
                close(sk);
@@ -262,7 +262,7 @@ if(errno == EINPROGRESS){
                printf("SMTP: scan_smtp_connect(8): retval 1 ERR\n"); 
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SMTP_33);
+                "(2)SMTP=%s IP=%s Port=%d %s %s", url_dom, ip_addr, port, SOCK_16, SMTP_33);
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
                close(sk);
@@ -270,22 +270,24 @@ if(errno == EINPROGRESS){
                return backdata;
                }
             else{
+               // 非同期通信から同期通信に
+               fcntl(sk, F_SETFL, 0);
 
                // fdに変化があったので読んでみたりするテスト
 //             dcount = recv(sk, recvdata, BUF_LEN, 0);
-               dcount = socket_reada(sk, recvdata, BUF_LEN);
+               dcount = socket_readas(sk, recvdata, BUF_LEN, timeout, 1);
 
                #ifdef SMTP_BUG
-               printf("SMTP: scan_smtp_connect(9): recv-- %s --\n", recvdata);
+               printf("SMTP: scan_smtp_connect(9): dcount=%d recv-- %s --\n", dcount, recvdata);
                #endif
+
                // 受信量が異常
                if(dcount < 1){
                   backdata = safe_sprintf(backdata,BUF_MAX,
-                   "URL=%s Port=%d %s"
-                   , url_dom, port, SMTP_22);
+                   "(3)SMTP=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SMTP_22);
                   ret = -1;
                   // 非同期通信から同期通信に
-                  fcntl(sk, F_SETFL, 0);
+//                fcntl(sk, F_SETFL, 0);
                   close(sk);
                   * pst = -1;
                   return backdata;
@@ -297,32 +299,34 @@ if(errno == EINPROGRESS){
 // printf("1 dcount=<%d>  SEND=<%s> \n RECV=<%s>\n", dcount, senddata, recvdata);
 
                   ch_char(recvdata, senddata);
-                  swap_mem(senddata, '\n', ' ');
+                  rm_char(senddata, '\r');
+                  rm_char(senddata, '\n');
+                  swap_mem(senddata, '\t', ' ');
                   swap_mem(senddata, ',', ' ');
 
                   ret = check_smrecvdata(recvdata);
                   // 受信ステータスが200番だいでない
                   if(ret < 0){
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", SMTP_11, senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"data=%s: %s", senddata, SMTP_11);
                      #ifdef SMTP_BUG
                      printf("SMTP: scan_smtp_bug(10): ret<%d><%d> recvdata<%s> backdata<%s>\n",
                        ret,*pst, recvdata, backdata);
                      #endif
                      // 非同期通信から同期通信に
-                     fcntl(sk, F_SETFL, 0);
+//                   fcntl(sk, F_SETFL, 0);
                      close(sk);
                      * pst = ret;
                      return backdata;
                      }
                   // 受信ステータスが200番だいです。
                   else{
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", SMTP_44, senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"data=%s: %s", senddata, SMTP_44);
                      #ifdef SMTP_BUG
                      printf("SMTP: scan_smtp_bug(11): ret<%d><%d> recvdata<%s> backdata<%s>\n",
                        ret,*pst, recvdata, backdata);
                      #endif
                      // 非同期通信から同期通信に
-                     fcntl(sk, F_SETFL, 0);
+//                   fcntl(sk, F_SETFL, 0);
                      break;
                      }
                   }
@@ -330,7 +334,7 @@ if(errno == EINPROGRESS){
             }  // while()
 
          // 非同期通信から同期通信に
-         fcntl(sk, F_SETFL, 0);
+//       fcntl(sk, F_SETFL, 0);
          dcount = 0;
 
 
@@ -341,7 +345,7 @@ if(errno == EINPROGRESS){
 
          //  SMTPから返事があったので、HELOを送ってステータスをまちます
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s", url_dom, port, SOCK_3);
+          "SMTP=%s IP=%s Port=%d %s", url_dom, ip_addr, port, SOCK_3);
          set_smrequest(senddata);
          #ifdef SMTP_BUG
          printf("SMTP: scan_smtp_connect(12): set_request*send-- %s --\n", senddata);
@@ -365,7 +369,7 @@ if(errno == EINPROGRESS){
                printf("SMTP: scan_smtp_connect(13): retval 0 ERR ===\n");
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SMTP_2);
+                "SMTP=%s IP=%s Port=%d %s %s", url_dom, ip_addr, port, SOCK_15, SMTP_2);
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
                close(sk);
@@ -378,7 +382,7 @@ if(errno == EINPROGRESS){
                printf("SMTP: scan_smtp_connect(14): retval 1 ERR\n"); 
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SMTP_3);
+                "SMTP=%s IP=%s Port=%d %s %s", url_dom, ip_addr, port, SOCK_16, SMTP_3);
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
                close(sk);
@@ -386,35 +390,40 @@ if(errno == EINPROGRESS){
                return backdata;
                }
             else{
+               // 非同期通信から同期通信に
+               fcntl(sk, F_SETFL, 0);
 
-//             dcount = recv(sk, recvdata, 256, 0);
-               dcount = socket_reada(sk, recvdata, BUF_LEN);
+               dcount = socket_readas(sk, recvdata, BUF_LEN, timeout, 1);
 
                #ifdef SMTP_BUG
-               printf("SMTP: scan_smtp_connect(15): recv-- %s --\n", recvdata);
+               printf("SMTP: scan_smtp_connect(15): dcount=%d recv-- %s --\n", dcount, recvdata);
                #endif
+
                // 受信量が異常
                if(dcount < 1){
                   backdata = safe_sprintf(backdata,BUF_MAX,
-                   "URL=%s Port=%d %s"
-                   , url_dom, port, SMTP_2);
+                   "SMTP=%s IP=%s Port=%d: %s" , url_dom, ip_addr, port, SMTP_2);
                   ret = -1;
                   }
                // 受信量は正常
                else{
 
-// printf("2 dcount=<%d> SEND=<%s> \n RECV=<%s>\n", dcount, senddata, recvdata);
+                  #ifdef SMTP_BUG
+                  printf("2 dcount=<%d> SEND=<%s> \n RECV=<%s>\n", dcount, senddata, recvdata);
+                  #endif
 
                   memset(senddata, 0x00, BUF_LEN);
 
                   ch_char(recvdata, senddata);
-                  swap_mem(senddata, '\n', ' ');
+                  rm_char(senddata, '\r');
+                  rm_char(senddata, '\n');
+                  swap_mem(senddata, '\t', ' ');
                   swap_mem(senddata, ',', ' ');
 
                   ret = check_smrecvdata(recvdata);
                   // 受信ステータスが200番だいでない
                   if(ret < 0){
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", SMTP_1, senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"data=%s: %s", senddata, SMTP_1);
                      #ifdef SMTP_BUG
                      printf("SMTP: scan_smtp_bug(16): <2> ret<%d><%d> recvdata<%s> backdata<%s>\n",
                        ret,*pst, recvdata, backdata);
@@ -422,7 +431,7 @@ if(errno == EINPROGRESS){
                      }
                   // 受信ステータスが200番だいです。
                   else{
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", SMTP_4, senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"data=%s: %s", senddata, SMTP_4);
                      #ifdef SMTP_BUG
                      printf("SMTP: scan_smtp_bug(17): <2> ret<%d><%d> recvdata<%s> backdata<%s>\n",
                        ret,*pst, recvdata, backdata);
@@ -430,7 +439,7 @@ if(errno == EINPROGRESS){
                      }
                   }
                // 非同期通信から同期通信に
-               fcntl(sk, F_SETFL, 0);
+//             fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = ret;
                return backdata;
@@ -451,7 +460,7 @@ if(errno == EINPROGRESS){
 // 非同期通信から同期通信に
 fcntl(sk, F_SETFL, 0);
 backdata=safe_sprintf(backdata,BUF_MAX,
- "URL=%s Port=%d %s", url_dom, port, SOCK_14);
+ "SMTP=%s IP=%s Port=%d %s", url_dom, ip_addr, port, SOCK_14);
 
 close(sk);
 * pst = -1;
