@@ -1,6 +1,4 @@
 
-#ifdef NET_SNMP_IN
-
 
 #include<stdio.h>
 #include<netinet/in.h>
@@ -15,218 +13,34 @@
 
 
 
-/*
-int scan_snmp(struct scan_buf *);
-*/
-
-
-char * cal_oid(char *, char *, int *, int *, char *, char *, int *, int);
-int cal4(int, int, char);
-int ch_en(char);
-
-
-char * cal_oid(char * oid, char * backdata, int * stat, int * ret, char * port, char * host, int *chk, int timeout)
-{ 
-char * da;
-int max, damax, co, count, sta, sto, lim, kaz;
-char calchar = '+';
-sta = 0;
-sto = 0;
-lim = 0;
-kaz = 0;
-damax = 0;
-
-max = strlen(oid);
-* stat = 0;
-* ret = 0;
-
-if(5 > max){
-   * stat = -1;
-   backdata = safe_sprintf(backdata, BUF_MAX,"%s\n", SNMP_1);
-   return backdata;
-   }
-co = char_count(oid, '[');
-if(0 < (co % 2)){
-   * stat = -1;
-   backdata = safe_sprintf(backdata, BUF_MAX,"%s\n", SNMP_2);
-   return backdata;
-   }
-
-if(0 == memcmp(oid, "cal", 3)){
-   for(count = 0; count < co; count++){
-      da = (char *)calloc(max, sizeof(char));
-      delim_count(oid, '[', count, &sta, &sto);
-      memcount_cpm(da, oid, sta, sto, max);
-      damax = (int)strlen(da);
-      if(damax > 0){
-         if(1 == damax && 0 == ch_en(da[0])){
-            calchar = da[0];
-            backdata = safe_sprintf(backdata, BUF_MAX,"%s (%c)\n", SNMP_3, calchar);
-            #ifdef SNMP_DEBUG
-            printf("SNMP_DEBUG: cal_oid(1): +-*/Da = %c\n", calchar);
-            #endif
-            }
-         else{
-            lim = char_count(da, '.');
-            if(lim == 0 && 0 < (int)strlen(da) && 0 == ch_int(da)){
-               kaz = strtol(da, (char **)NULL, 10);
-               backdata = safe_sprintf(backdata, BUF_MAX,"%s (%d)\n", SNMP_22, kaz);
-               #ifdef SNMP_DEBUG
-               printf("SNMP_DEBUG: cal_oid(2): 1234Da = %d\n", kaz);
-               #endif
-               * ret = cal4(* ret, kaz, calchar);
-               kaz = 0;
-               }
-            else{
-               if(0 != memcmp(da, "cal", 3)){
-                  backdata = snmp_test(backdata, port, host, da, stat, 2, chk, timeout);
-                  #ifdef SNMP_DEBUG
-                  printf("SNMP_DEBUG: cal_oid(3): M->OID Da = %s %d %s %d\n", da, *chk, backdata, *stat);
-                  #endif
-                  if(* stat >= 0 && * chk < 4){
-                     kaz = strtol(backdata, (char **)NULL, 10);
-                     backdata = safe_sprintf(backdata, BUF_MAX,
-                     "%s OID (%s) (%d)\n", SNMP_7, da, kaz);
-                     * ret = cal4(* ret, kaz, calchar);
-                     kaz = 0;
-                     }
-                  else{
-                     * stat = -1;
-                     * ret = 0;
-                     #ifdef SNMP_DEBUG
-                     printf("SNMP_DEBUG: cal_oid(4): %s OID<%s>\n", SNMP_5, da);
-                     #endif
-                     backdata = safe_sprintf(backdata, BUF_MAX, "%s OID<%s>\n", SNMP_5, da);
-                     return backdata;
-                     }
-                  }
-               else{
-                  #ifdef SNMP_DEBUG
-                  printf("SNMP_DEBUG: cal_oid(5): head string is 'cal' Da = %s\n", da);
-                  #endif
-                  }
-              }
-            lim = 0;
-            }
-         }
-      else{
-         fprintf(stderr,"cal_oid(): Da size = 0\n");
-         }      
-      free(da);
-      }
-   }
-else{
-   lim = char_count(oid, '.');
-   if(lim == 0 && 0 < (int)strlen(oid) && 0 == ch_int(oid)){
-      kaz = strtol(oid, (char **)NULL, 10);
-      backdata = safe_sprintf(backdata, BUF_MAX,
-      "%s (%s) stat(%d)\n", SNMP_22, oid, kaz);
-      * ret = cal4(* ret, kaz, calchar);
-      kaz = 0;
-      }
-   else{
-      backdata = snmp_test(backdata, port, host, oid, stat, 2, chk, timeout);
-      #ifdef SNMP_DEBUG
-      printf("SNMP_DEBUG: cal_oid(6): S->OID Da = %s %d %s\n", oid, * stat, backdata);
-      #endif
-      if(* stat >= 0 && * chk < 4){
-         kaz = strtol(backdata, (char **)NULL, 10);
-         backdata = safe_sprintf(backdata, BUF_MAX,
-         "%s OID (%s) (%d)\n", SNMP_7, oid, kaz);
-         * ret = cal4(* ret, kaz, calchar);
-         kaz = 0;
-         }
-      else{
-         * stat = -1;
-         * ret = 0;
-         #ifdef SNMP_DEBUG
-         printf("SNMP_DEBUG: cal_oid(7): %s OID<%s> stat<%d>\n", SNMP_5, oid, * stat);
-         #endif
-         backdata = safe_sprintf(backdata, BUF_MAX, "%s OID<%s> stat<%d>\n", SNMP_5, oid, * stat);
-         return backdata;
-         }
-      }
-   }
-
-if(* stat >= 0){
-   backdata = safe_sprintf(backdata, BUF_MAX,
-   "%s ret (%d)\n", SNMP_9, * ret);
-   }
-
-return backdata;
-}
-
-
-
-/* ------ CH_EN ------ */
-int ch_en(char chA)
-{
-int ret = 0;
-
-if(chA == '+' || chA == '-' || chA == '*' || chA == '/'){
-   ret = 0;
-   }
-else{
-   ret = -1;
-   }
-
-return ret;
-}
-
-
-
-
-
-/* ------ CAL4 ------- */
-int cal4(int inA, int inB, char chA)
-{
-int ret = 0;
-
-if(chA == '+'){
-   ret = inA + inB;
-   return ret;
-   }
-else if(chA == '-'){
-   ret = inA - inB;
-   return ret;
-   }
-else if(chA == '*'){
-   ret = inA * inB;
-   return ret;
-   }
-else if(chA == '/'){
-   if(inA != 0 && inB != 0){ 
-      ret = (int)(inA / inB);
-      }
-   else{
-      ret = 0;
-       }
-   return ret;
-   }
-else{
-   fprintf(stderr,"cal4(): (%d) %s\n", ret, SNMP_24);
-   return ret;
-   }
-
-return 0;
-}
-
-
-
 
 /* ------ SCAN PORT --------- */
 int scan_snmp(struct scan_buf *pd)
 {
-int ret, hi, inret, chk, plai;
+int ret, hi, inret, chk, plai, stats, in1, in2;
 ret = 0;
 hi = 0;
 inret = 0;
 chk = 0;
 plai = 0;
+stats = 0;
+in1 = 0;
+in2 = 0;
 
-char * chhi = (char *)calloc(IP_LEN, sizeof(char));
-char * chho = (char *)calloc(IP_LEN, sizeof(char));
-char * backdata = (char *)calloc(IP_LEN, sizeof(char));
+char ch[1024];
+char ho[1024];
+char bk[1024];
+
+char * chhi = ch;
+char * chho = ho;
+char * backdata = bk;
+
+memset(chhi, 0x00, 1024);
+memset(chho, 0x00, 1024);
+memset(backdata, 0x00, 1024);
+
+pd->swap = null_free(pd->swap);
+pd->swap_2 = null_free(pd->swap_2);
 
 if(0 == ch_int2(pd->ch_plai)){
    plai = strtol(pd->ch_plai, (char **)NULL, 10);
@@ -238,8 +52,10 @@ else{
 // 閾値がNOTの場合、戻り値は編集しないでそのまま返す
 if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
-   backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_23);
-   pd->ch_info = safe_memcpy(pd->ch_info, backdata, BUF_MAX);
+
+   self_memcpy(backdata, pd->ch_info, 1024);
+   pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"(%s) %s\n", backdata, SNMP_23);
+
    #ifdef SNMP_DEBUG
    printf("SNMP_DEBUG: scan_snmp(): ch_info = <%s>: inret = <%d>: stat = <%d>\n", pd->ch_info, inret, ret);
    #endif
@@ -265,10 +81,151 @@ else if(0 == memcmp(pd->ch_prot, "LOG", 3) || 0 == memcmp(pd->ch_port, "log", 3)
       }
    }
 
+
+
+// 閾値の先頭が|で最後か|であり敷居が|である、克つ全体が5文字以上な場合
+else if(pd->ch_prot[0] == '|' && 4 < (int)strlen(pd->ch_prot) &&
+   pd->ch_prot[((int)strlen(pd->ch_prot)) - 1] == '|' && 3 == char_count(pd->ch_prot, '|')){
+   if(pd->ch_prot[1] != '|' && 0 != isdigit(pd->ch_prot[1]) && 0 != isdigit(pd->ch_prot[((int)strlen(pd->ch_prot)) - 2])){
+
+      pd->swap = delim_get(pd->ch_prot, pd->swap, '|', &stats, 1);
+      pd->swap_2 = safe_memcpy(pd->swap_2, (pd->swap + 1), BUF_LEN);
+      pd->swap = delim_get(pd->ch_prot, pd->swap, '|', &stats, 2);
+
+      if(0 == ch_int2(pd->swap_2) && 0 == ch_int2(pd->swap)){
+
+         in1 = strtol(pd->swap_2, (char **)NULL, 10);
+         in2 = strtol(pd->swap, (char **)NULL, 10);
+
+         #ifdef SNMP_DEBUG
+         printf("BUG BUG swap2 %d , %d\n", in1, in2);
+         #endif
+         if(in2 >= in1){
+            pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
+            if(4 == chk){
+               #ifdef SNMP_DEBUG
+               printf("SNMP_DEBUG: scan_snmp(||): %s %s in1=%d in2=%d inret=%d\n", pd->ch_info, pd->ch_free1, in1, in2, inret);
+               #endif
+               ret = -1;
+
+               self_memcpy(backdata, pd->ch_info, 1024);
+               pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"(%s) %s\n", backdata, SNMP_30);
+
+               }
+            else if(0 > ret){
+               if(0 == (int)strlen(pd->ch_info)){
+                  ret = -1;
+                  pd->ch_info=safe_sprintf(pd->ch_info, BUF_MAX,"%s\n",SNMP_10);
+                  }
+               }
+            else{
+               if(inret >= in1 && inret <= in2){
+                  // ok
+                  ret = 0;
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < return %d > %d %s\n", in1, inret, in2, SNMP_32);
+                  }
+               else{
+                  // ng
+                  ret = -1;
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < !return %d > %d %s\n", in1, inret, in2, SNMP_33);
+                  }
+               }
+            }
+         else{
+            ret = -1;
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%s %s\n",pd->ch_prot, SNMP_34);
+            }
+         }
+      else{
+         ret = -1;
+         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"2 %s %s\n",pd->ch_prot, SNMP_13);
+         }
+      }
+   else{
+      ret = -1;
+      pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"3 %s %s\n",pd->ch_prot, SNMP_13);
+      }
+   }
+
+
+
+
+
+// 閾値の先頭が&で最後か&であり敷居が&である、克つ全体が5文字以上な場合
+else if(pd->ch_prot[0] == '&' && 4 < (int)strlen(pd->ch_prot) &&
+   pd->ch_prot[((int)strlen(pd->ch_prot)) - 1] == '&' && 3 == char_count(pd->ch_prot, '&')){
+   if(pd->ch_prot[1] != '&' && 0 != isdigit(pd->ch_prot[1]) && 0 != isdigit(pd->ch_prot[((int)strlen(pd->ch_prot)) - 2])){
+
+      pd->swap = delim_get(pd->ch_prot, pd->swap, '&', &stats, 1);
+      pd->swap_2 = safe_memcpy(pd->swap_2, (pd->swap + 1), BUF_LEN);
+      pd->swap = delim_get(pd->ch_prot, pd->swap, '&', &stats, 2);
+
+      if(0 == ch_int2(pd->swap_2) && 0 == ch_int2(pd->swap)){
+
+         in1 = strtol(pd->swap_2, (char **)NULL, 10);
+         in2 = strtol(pd->swap, (char **)NULL, 10);
+
+         #ifdef SNMP_DEBUG
+         printf("BUG BUG swap2 %d , %d\n", in1, in2);
+         #endif
+         if(in2 >= in1){
+            pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
+            if(4 == chk){
+               #ifdef SNMP_DEBUG
+               printf("SNMP_DEBUG: scan_snmp(||): %s %s in1=%d in2=%d inret=%d\n", pd->ch_info, pd->ch_free1, in1, in2, inret);
+               #endif
+               ret = -1;
+
+               self_memcpy(backdata, pd->ch_info, 1024);
+               pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"(%s) %s\n", backdata, SNMP_30);
+
+               }
+            else if(0 > ret){
+               if(0 == (int)strlen(pd->ch_info)){
+                  ret = -1;
+                  pd->ch_info=safe_sprintf(pd->ch_info, BUF_MAX,"%s\n",SNMP_10);
+                  }
+               }
+            else{
+               if(inret <= in1 || in2 <= inret){
+                  // ok
+                  ret = 0;
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < return %d > %d %s\n", in1, inret, in2, SNMP_32);
+                  }
+               else{
+                  // ng
+                  ret = -1;
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < !return %d > %d %s\n", in1, inret, in2, SNMP_33);
+                  }
+               }
+            }
+         else{
+            ret = -1;
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%s %s\n",pd->ch_prot, SNMP_34);
+            }
+         }
+      else{
+         ret = -1;
+         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"2 %s %s\n",pd->ch_prot, SNMP_13);
+         }
+      }
+   else{
+      ret = -1;
+      pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"3 %s %s\n",pd->ch_prot, SNMP_13);
+      }
+   }
+
+
+
+
+
+
+
 // 閾値の先頭がマイナスの場合
 else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
 
-   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
+// chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
+   self_memcpy(chhi, pd->ch_prot + 1, 1024);
    if(-1 != ch_int(chhi)){
       if((hi = strtol(chhi, (char **)NULL, 10)) >= 0){
          pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
@@ -277,8 +234,10 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
          #endif
          if(4 == chk){
             ret = -1;
-            backdata=safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_30);
-            pd->ch_info = safe_memcpy(pd->ch_info, backdata, BUF_MAX);
+ 
+            self_memcpy(backdata, pd->ch_info, 1024);
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"(%s) %s\n", backdata, SNMP_30);
+
             }
          else if(0 > ret){
             if(0 == (int)strlen(pd->ch_info)){
@@ -290,7 +249,7 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
             if(hi > inret){
                ret = -1;
                if(0 < plai && 5 > plai){
-                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"1 %d > %d %s\n", hi, inret, SNMP_11);
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d > %d %s\n", hi, inret, SNMP_11);
                   }
                else{
                   pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d\n", inret);
@@ -299,7 +258,7 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
             else{
                ret = 0;
                if(0 < plai && 5 > plai){
-                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"3 %d < %d %s\n", hi, inret, SNMP_12);
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < %d %s\n", hi, inret, SNMP_12);
                   }
                else{
                   pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d\n", inret);
@@ -318,9 +277,13 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
       } 
    }
 
+
+
+
 // 閾値の先頭が＋の場合
 else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
-   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
+// chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
+   self_memcpy(chhi, pd->ch_prot + 1, 1024);
    if(-1 != ch_int(chhi)){
       if((hi = strtol(chhi, (char **)NULL, 10)) >= 0){
          pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
@@ -329,8 +292,10 @@ else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
          #endif
          if(4 == chk){
             ret = -1;
-            backdata=safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_30);
-            pd->ch_info = safe_memcpy(pd->ch_info, backdata, BUF_MAX);
+
+            self_memcpy(backdata, pd->ch_info, 1024);
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"(%s) %s\n", backdata, SNMP_30);
+
             }
          else if(0 > ret){
             if(0 == (int)strlen(pd->ch_info)){
@@ -372,10 +337,21 @@ else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
 
 // 閾値の先頭が！の場合
 else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
-   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
-   pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
+// chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
+   self_memcpy(chhi, pd->ch_prot + 1, 1024);
+
+   if(0 == memcmp(pd->ch_com, "cal", 3)){
+      pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
+      if(ret > -1){
+         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d", inret);
+         }
+      }
+   else{
+      pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
+      }
+
    #ifdef SNMP_DEBUG
-   printf("SNMP_DEBUG: scan_snmp(): %s\n%s\n%s\n", pd->ch_info, pd->ch_free1, chhi);
+   printf("SNMP_DEBUG: scan_snmp(!): %s %s %s ret= %d\n", pd->ch_info, pd->ch_free1, chhi, ret);
    #endif
    if(0 > ret){
       if(0 == (int)strlen(pd->ch_info)){
@@ -384,7 +360,9 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
          }
       }
    else{
-      chho = safe_memcpy(chho, pd->ch_info, BUF_MAX);
+//    chho = safe_memcpy(chho, pd->ch_info, BUF_MAX);
+      self_memcpy(chho, pd->ch_info, 1024);
+      // 同じ返事を返していない（！なので異常）
       if(0 != self_memcmp(chhi, chho)){
          ret = -1;
          if(0 < plai && 5 > plai){
@@ -395,6 +373,7 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
             pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s\n", chho);
             }
          }
+      // 同じ返事を返している（！なので正常）
       else{
          ret = 0;
          if(0 < plai && 5 > plai){
@@ -411,10 +390,21 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
 
 // 閾値の先頭が＝の場合
 else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
-   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
-   pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
+// chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
+   self_memcpy(chhi, pd->ch_prot + 1, 1024);
+
+   if(0 == memcmp(pd->ch_com, "cal", 3)){
+      pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
+      if(ret >= 0){
+         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d", inret);
+         }
+      }
+   else{
+      pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
+      }
+
    #ifdef SNMP_DEBUG
-   printf("SNMP_DEBUG: scan_snmp(): %s\n%s\n%s\n", pd->ch_info, pd->ch_free1, chhi);
+   printf("SNMP_DEBUG: scan_snmp(=): %s %s %s ret = %d\n", pd->ch_info, pd->ch_free1, chhi, ret);
    #endif
    if(0 > ret){
       if(0 == (int)strlen(pd->ch_info)){
@@ -423,9 +413,12 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
          }
       }
    else{
-      chho = safe_memcpy(chho, pd->ch_info, BUF_MAX);
+//    chho = safe_memcpy(chho, pd->ch_info, BUF_MAX);
+      self_memcpy(chho, pd->ch_info, 1024);
+      // 同じ返事を返していない（＝なので正常）
       if(0 != self_memcmp(chhi, chho)){
          ret = 0;
+
          if(0 < plai && 5 > plai){
             pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
                "%s\n                   1(%s)\n                   2(%s)\n", SNMP_19, chhi, chho);
@@ -434,6 +427,7 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
             pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s\n", chho);
             }
          }
+      // 同じ返事を返している（＝なので異常）
       else{
          ret = -1;
          if(0 < plai && 5 > plai){
@@ -451,8 +445,10 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
 // それ以外の場合もNOTと同じ処理、但し間違いを正す。
 else {
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
-   backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_13);
-   pd->ch_info = safe_memcpy(pd->ch_info, backdata, BUF_MAX);
+
+   self_memcpy(backdata, pd->ch_info, 1024);
+   pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"(%s) %s\n", backdata, SNMP_13);
+
    #ifdef SNMP_DEBUG
    printf("SNMP_DEBUG: scan_snmp(): %s\n%s", pd->ch_info, pd->ch_free1);
    printf("SNMP_DEBUG: scan_snmp(): backdata = <%s>: inret = <%d>: stat = <%d>\n", backdata, inret, ret);
@@ -523,18 +519,13 @@ if(ret >= 0){
    }
 
 
-free(chhi);
-free(chho);
-free(backdata);
-
 #ifdef SNMP_DEBUG
-printf("SNMP_DEBUG: scan_snmp(): ch_info = <%s>: inret = <%d>: stat = <%d>\n", pd->ch_info, inret, ret);
+printf("SNMP_DEBUG: scan_snmp(last): ch_info = <%s>: inret = <%d>: stat = <%d>\n", pd->ch_info, inret, ret);
 #endif
 
 return(ret);
 }
 
 
-#endif
 
 
