@@ -77,9 +77,9 @@ if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
    backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
    }
 else{
-   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret, '4');
    if(resolv_ret < 0){
-      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret, '4');
       fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
       }
    }
@@ -110,7 +110,7 @@ re = connect(sk, (struct sockaddr *)(long)&my_addr, sizeof(my_addr));
 
 if(re >= 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
-    "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_3);
+    "HOST=%s IP=%s Port=%d TCP %s", ip_addr, ip_addr2, port, SOCK_3);
    #ifdef TCP_BUG
    printf("TCP: scan_tcp_connect(4): CONNECT SUCCESS %s\n", backdata);
    #endif
@@ -130,7 +130,7 @@ if(errno == EINPROGRESS){
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
       if(retval < 0){
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "IP=%s Port=%d %s %s", ip_addr, port, SOCK_15, SOCK_5);
+          "HOST=%s IP=%s Port=%d %s %s", ip_addr, ip_addr2, port, SOCK_15, SOCK_5);
          #ifdef TCP_BUG
          printf("TCP: scan_tcp_connetc(5): select err BREAK-%d- %s\n", retval, backdata);
          #endif
@@ -141,7 +141,7 @@ if(errno == EINPROGRESS){
          }
       else if(retval == 0){
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "IP=%s Port=%d %s %s", ip_addr, port, SOCK_16, SOCK_5);
+          "HOST=%s IP=%s Port=%d %s %s", ip_addr, ip_addr2, port, SOCK_16, SOCK_5);
          #ifdef TCP_BUG
          printf("TCP: scan_tcp_connetc(6): select time out BREAK-%d- %s\n", retval, backdata);
          #endif
@@ -152,7 +152,7 @@ if(errno == EINPROGRESS){
          }
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_3);
+          "HOST=%s IP=%s Port=%d TCP %s", ip_addr, ip_addr2, port, SOCK_3);
          #ifdef TCP_BUG
          printf("TCP: scan_tcp_connect(7): select time succes BREAK-%d- %s\n", retval, backdata);
          #endif
@@ -164,7 +164,7 @@ if(errno == EINPROGRESS){
 
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
       backdata=safe_sprintf(backdata,BUF_MAX,
-       "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_13);
+       "HOST=%s IP=%s Port=%d TCP %s", ip_addr, ip_addr2, port, SOCK_13);
       #ifdef TCP_BUG
       printf("TCP: scan_tcp_connect(8): getsockopt() Errors!\n");
       #endif
@@ -175,7 +175,7 @@ if(errno == EINPROGRESS){
    else{
       if(retval){
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "IP=%s Port=%d %s: TCP %s", ip_addr, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
+          "HOST=%s IP=%s Port=%d %s: TCP %s", ip_addr, ip_addr2, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
          #ifdef TCP_BUG
          printf("TCP: scan_tcp_connect(9): 1 SO_ERROR %d -\n", retval);
          printf("%s\n", backdata);
@@ -186,7 +186,7 @@ if(errno == EINPROGRESS){
          }
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_3);
+          "HOST=%s IP=%s Port=%d TCP %s", ip_addr, ip_addr2, port, SOCK_3);
          #ifdef TCP_BUG
          printf("TCP: scan_tcp_connect(10): -1 SO_ERROR %d -\n", retval);
          printf("%s\n", backdata);
@@ -201,7 +201,7 @@ if(errno == EINPROGRESS){
 fcntl(sk, F_SETFL, 0);
 
 backdata=safe_sprintf(backdata,BUF_MAX,
- "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_14); 
+ "HOST=%s IP=%s Port=%d TCP %s", ip_addr, ip_addr2, port, SOCK_14); 
 #ifdef TCP_BUG
 printf("TCP: scan_tcp_connect(11): --- LAST END ---\n");
 printf("%s\n", backdata);
