@@ -66,9 +66,9 @@ if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
    backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
    }
 else{
-   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret, '4');
    if(resolv_ret < 0){
-      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret, '4');
       fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
       }
    }
@@ -95,7 +95,7 @@ printf("UDP: scan_udp_connect(2): UDP host<%s> ip<%s>\n",ip_addr2, ip_addr);
 
 if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
-    "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_1);
+    "HOST=%s IP=%s Port=%d UDP %s", ip_addr, ip_addr2, port, SOCK_1);
    #ifdef UDP_BUG
    printf("UDP: scan_udp_connect(3): SEND UDP PACKET %s\n", backdata);
    #endif
@@ -105,7 +105,7 @@ if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
 
 if((recv_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
-    "IP=%s Port=%d ICMP %s", ip_addr, port, SOCK_1);
+    "HOST=%s IP=%s Port=%d UDP %s", ip_addr, ip_addr2, port, SOCK_1);
    * stat = -10;
    #ifdef UDP_BUG
    printf("UDP: scan_udp_connect(4): SEND ROW PACKET %s\n", backdata);
@@ -149,7 +149,7 @@ while(1){
          }
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
-           "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_7);
+           "HOST=%s IP=%s Port=%d UDP %s", ip_addr, ip_addr2, port, SOCK_7);
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(7): ");
          #endif
@@ -164,8 +164,7 @@ while(1){
       struct servent *se;
       se = getservbyport(htons(port), "udp");
       backdata=safe_sprintf(backdata,BUF_MAX,
-       "IP=%s Port=%d %s UDP %s",
-         ip_addr, port, (se==NULL)?"unknown":se->s_name, SOCK_3);
+       "HOST=%s IP=%s Port=%d %s UDP %s", ip_addr, ip_addr2, port, (se==NULL)?"unknown":se->s_name, SOCK_3);
       #ifdef UDP_BUG
       printf("UDP: scan_udp_connect(8): RECV %s", backdata);
       #endif
@@ -182,7 +181,7 @@ while(1){
    }
 
 backdata=safe_sprintf(backdata,BUF_MAX,
- "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_5);
+ "HOST=%s IP=%s Port=%d UDP %s", ip_addr, ip_addr2, port, SOCK_5);
 #ifdef UDP_BUG
 printf("UDP: scan_udp_connect(10): END %s", backdata);
 #endif
