@@ -36,7 +36,8 @@
   // sitar.conf のTHREAD_MAX で設定可能
 
 
-  #define B_LEN   256
+  #define B_LEN   64
+  // パトロール用 #define B_LEN   512
 
 
   // L_LEN は
@@ -47,7 +48,8 @@
   // sitar.conf のTHREAD_LEN で設定可能です。
 
 
-  #define L_LEN    12
+  #define L_LEN    4
+  // パトロール用  #define L_LEN    12
 
 
   // B_MAX は
@@ -59,7 +61,8 @@
   // ブロックを細かく分けて、この数字を小さくするとメモリーを節約可能
 
 
-  #define B_MAX    128
+  #define B_MAX    64
+  // パトロール用  #define B_MAX    128
 
 
   // B_MID
@@ -67,7 +70,8 @@
   // 充分な数を指定してください。B_LEN と同じがベストですが、減らすことでメモリーの節約が出来ます。
   // sitar.conf のMID_MAXで設定可能
 
-  #define B_MID    1024
+  #define B_MID    64
+  // パトロール用  #define B_MID    1240
 
   // L_LENの値の排他処理での待ち時間
 
@@ -230,6 +234,17 @@
    typedef struct private_data private_data_t;
 
    struct private_data{
+      struct db_data{
+         char * swap;
+         char * swap1;
+         char * swap2;
+         char * server;
+         char * username;
+         char * passwd;
+         char * database;
+         int port;
+         int timeout;
+         }db;
       struct scan_buf{
          int fdno;
          char * swap;             /* active swap */
