@@ -17,19 +17,19 @@
 //  #define PEXEC_DEBUG
 //  #define PEXEC_MUTEX_DEBUG
 
-  int * pids[COM_LEN];
-  int pids_count[COM_LEN];
-  int pids_count2[COM_LEN];
+//  int * pids[COM_LEN];
+//  int pids_count[COM_LEN];
+//  int pids_count2[COM_LEN];
 
   /* -- p_exec.c -- */
   char * execom(char *, char *, int, int);
   char * out_execom(char *, char *, int, int);
 
   /* -- p_open.c BSD2.11 -- */
-  int p_pclose(FILE *, int);
+  int p_pclose(FILE *, int, int);
   FILE * p_popen(FILE *, char *, register char *, int *, int *, int, int);
-  int out_p_pclose(FILE *, int);
-  FILE * out_p_popen(FILE *, char *, register char *, int *, int *, int, int);
+//  int out_p_pclose(FILE *, int);
+//  FILE * out_p_popen(FILE *, char *, register char *, int *, int *, int, int);
 
 #endif
 
