@@ -3,7 +3,11 @@
 
 // #include"config.h" 
 
-   #define CL_LINTVER "zither_lint-1.0.0"
+   #ifndef _VERSION_H_
+      #include "version.h"
+   #endif
+
+   #define CL_LINTVER "zither_lint-"VERSION
 
    #ifndef BUF_DEFLEN 
       #define BUF_DEFLEN 128
