@@ -31,7 +31,7 @@ int cgstat = self_memcmp(pd->rec.user, "cgiuser");
 
 if(ustat == 0 && astat != 0 && cgstat != 0){ 
    #ifdef LOG_OUT
-   pthread_mutex_lock(&con_mutex);
+   safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data, "", gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
@@ -42,7 +42,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
 else{
    stat = socket_send(gd.ms.sk[pd->rec.fdno], "500 NG No permit.\n", (pd->life.life_int + pd->life.life_los + 15));
    #ifdef LOG_OUT
-   pthread_mutex_lock(&con_mutex);
+   safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
      "500 NG No permit.", gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
