@@ -134,21 +134,26 @@ for(;;){
 
    if(2 < (int)strlen(recdata)){
 
-   // subject を作ります
-      swapsubject = make_subject(swapsubject, CLIENT_BODY_4, "administrator");
+      if(gd.md.in_mailonoff == 1){
 
-   // 本文を作ります
-      swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", CLIENT_BODY_3, recdata, CL_VAR);
-      swap_mem(swapdata, '\n', (char)0x01);
+      // subject を作ります
+         swapsubject = make_subject(swapsubject, CLIENT_BODY_4, "administrator");
+
+      // 本文を作ります
+         swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", CLIENT_BODY_3, recdata, CL_VAR);
+         swap_mem(swapdata, '\n', (char)0x01);
+
+         mail_grsend(gd.md.ch_MailServ,
+                 gd.md.ch_MailFrom,
+                 gd.md.ch_MailRcptTo,
+                 " ",
+                 swapdata,
+                 swapsubject,
+                 gd.on_bcc,
+                 "1");
+
+            }   
 
-      mail_grsend(gd.md.ch_MailServ,
-              gd.md.ch_MailFrom,
-              gd.md.ch_MailRcptTo,
-              " ",
-              swapdata,
-              swapsubject,
-              gd.on_bcc,
-              "1");
       }
 
    free(recdata);
