@@ -16,7 +16,7 @@
 #define MAIL_BODY_1 "Υ֥åϥ᡼ˡưַ⡼1ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬3Ϣ³ƹԤɬפޤ\n\n\n"
 #define MAIL_BODY_2 "Υ֥åϥ᡼ˡưַ⡼2ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬Ԥɬפޤ\n\n\n"
 
-#define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\n̵꤬Τ륤餫⤷ޤ \r\nǰΤᡢôԤ˳ǧƤߤƤ  "
+#define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\n̵꤬Τ륤餫⤷ޤ\nǰΤᡢôԤ˳ǧƤߤƤ "
 
 #define ADMIN_BODY_2 "ưѹԤޤ "
 
@@ -109,6 +109,32 @@
 #define MAIL_DHW_28 "ƻ  : "
 #define MAIL_DHW_29 "Error   : "
 
+
+
+#define MAIL_MYSQL_11 "-- MYSQLؤ䤤碌ǥ顼Τޤ --"
+#define MAIL_MYSQL_12 "      : "
+#define MAIL_MYSQL_13 "ץȥ  : "
+#define MAIL_MYSQL_14 "³    : " 
+#define MAIL_MYSQL_15 "꡼    : "
+#define MAIL_MYSQL_16 "ݡ      : "
+#define MAIL_MYSQL_17 "Ԥ    : "
+#define MAIL_MYSQL_18 "ƻ    : "
+#define MAIL_MYSQL_19 "ƻ  : "
+#define MAIL_MYSQL_20 "Error   : "
+
+#define MAIL_MYSQL_21 "-- MYSQLؤ䤤碌˹ԤƤޤ --"
+#define MAIL_MYSQL_22 "      : "
+#define MAIL_MYSQL_23 "ץȥ  : "
+#define MAIL_MYSQL_24 "³    : " 
+#define MAIL_MYSQL_25 "꡼    : "
+#define MAIL_MYSQL_26 "ݡ      : "
+#define MAIL_MYSQL_27 "Ԥ    : "
+#define MAIL_MYSQL_28 "ƻ    : "
+#define MAIL_MYSQL_29 "ƻ  : "
+#define MAIL_MYSQL_30 "Error   : "
+
+
+
 #define MAIL_URL_11 "-- ʲURLޤ --"
 #define MAIL_URL_12 "      : "
 #define MAIL_URL_13 "ץȥ  : "
