@@ -369,6 +369,34 @@ if(pri < 3){
            MAIL_DHW_19,
            info);
          }
+
+
+      else if(0 == self_memcmp(prot, "MYSQL")){
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+           MAIL_MYSQL_11,
+           kanshi,
+           MAIL_MYSQL_12,
+           pri_data,
+           MAIL_MYSQL_13,
+           prot,
+           MAIL_MYSQL_14,
+           host,
+           MAIL_MYSQL_15,
+           com,
+           MAIL_MYSQL_16,
+           port,
+           MAIL_MYSQL_17,
+           timeout,
+           MAIL_MYSQL_18,
+           free1,
+           MAIL_MYSQL_19,
+           data,
+           MAIL_MYSQL_20,
+           info);
+         }
+
+
+
       else if(0 == self_memcmp(prot, "URL")){
 //       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
          swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
@@ -482,6 +510,7 @@ if(pri < 3){
       }
 
    if(0 == self_memcmp(stat, "1") && 0 == self_memcmp(tool, "PORT")){
+
       if(0 == self_memcmp(prot, "DHW")){
 //       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
          swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
@@ -504,6 +533,33 @@ if(pri < 3){
            MAIL_DHW_29,
            info);
          }
+
+
+      else if(0 == self_memcmp(prot, "MYSQL")){
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+           MAIL_MYSQL_21,
+           kanshi,
+           MAIL_MYSQL_22,
+           pri_data,
+           MAIL_MYSQL_23,
+           prot,
+           MAIL_MYSQL_24,
+           host,
+           MAIL_MYSQL_25,
+           com,
+           MAIL_MYSQL_26,
+           port,
+           MAIL_MYSQL_27,
+           timeout,
+           MAIL_MYSQL_28,
+           free1,
+           MAIL_MYSQL_29,
+           data,
+           MAIL_MYSQL_30,
+           info);
+         }
+
+
       else if(0 == self_memcmp(prot, "URL")){
 //       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
          swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
