@@ -14,25 +14,32 @@
 #include"jpreturn.h"
 
 
+// V6 対応
+
 extern global_data_t gd;
 
 
 /*--------------- NEG_LOGIC ------------------- */
 int neg_logi(private_data_t * pd)
 {
-static int stat;
-stat = 0;
-int count = 0;
+int stat, sostat;
+int count;
 char * tmp;
 char * swapsubject;
 char * swapdata;
 
+stat = 0;
+sostat = 0;
+count = 0;
+
 if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
    pd->file.lock_filename = chack_lockfile(pd->rec.user, pd->rec.info, pd->file.lock_filename, gd.fp.lock_path, &stat);
 
    pd->file.clock_filename = filename_create(pd->file.clock_filename, gd.fp.clock_path, "_lock", pd->rec.user);
    lock_remove(pd->file.clock_filename);
 
+
+
    #ifdef DEBUG
    printf("DEBUG: neg_logi(): my lock file name & path. %s\n", pd->file.lock_filename);
    printf("DEBUG: neg_logi(): my clock file name & path. %s\n", pd->file.clock_filename);
@@ -102,7 +109,7 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
 
 
       #ifdef LOG_OUT
-      pthread_mutex_lock(&con_mutex);
+      safe_pthread_mutex_lock(&con_mutex);
       log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
         "It was newly connected.", gd.ms.inip_addr[pd->rec.fdno]);
       pthread_mutex_unlock(&con_mutex);
@@ -111,14 +118,11 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       #ifdef POSTGRES_IN
       char * pgerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
       char * swap = (char *)calloc(2, sizeof(char));
-      swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%s','%s','%s','%ld','%ld','%s','%s','%ld','%s','%s','%s','%s');",
+      swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%s','%s','%s','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%s','%s','%s','%ld','%ld','%s','%s','%ld','%s','%s','%s','%s');",
         "INSERT INTO errlog ",
         pgerrlog_table,
         " VALUES ",
-        gd.ms.inip_addr[pd->rec.fdno][0],
-        gd.ms.inip_addr[pd->rec.fdno][1],
-        gd.ms.inip_addr[pd->rec.fdno][2],
-        gd.ms.inip_addr[pd->rec.fdno][3],
+        gd.ms.inip_addr[pd->rec.fdno],
         pd->rec.user,
         "CONNECT",
         (long int)time(NULL),
@@ -146,7 +150,7 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       printf("POSTGRES_DEBUG: neg_logi(): %s\n", swap);
       #endif
 
-      pthread_mutex_lock(&pg_mutex);
+      safe_pthread_mutex_lock(&pg_mutex);
       psqlexec_datain(pd, swap);
       pthread_mutex_unlock(&pg_mutex);
       free(swap);
@@ -157,14 +161,11 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       #ifdef MYSQL_IN
       char * myerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
       char * myswap = (char *)calloc(2, sizeof(char));
-      myswap = safe_sprintf(myswap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%s','%s','%s','%ld','%ld','%s','%s','%ld','%s','%s','%s','%s');",
+      myswap = safe_sprintf(myswap, BUF_MAX, "%s%s%s('%s','%s','%s','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%s','%s','%s','%ld','%ld','%s','%s','%ld','%s','%s','%s','%s');",
         "INSERT INTO errlog ",
         myerrlog_table,
         " VALUES ",
-        gd.ms.inip_addr[pd->rec.fdno][0],
-        gd.ms.inip_addr[pd->rec.fdno][1],
-        gd.ms.inip_addr[pd->rec.fdno][2],
-        gd.ms.inip_addr[pd->rec.fdno][3],
+        gd.ms.inip_addr[pd->rec.fdno],
         pd->rec.user,
         "CONNECT",
         (long int)time(NULL),
@@ -192,7 +193,7 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       printf("MYSQL_DEBUG: neg_logi(): %s\n", myswap);
       #endif
 
-      pthread_mutex_lock(&mysql_mutex);
+      safe_pthread_mutex_lock(&mysql_mutex);
       mysqlexec_datain(myswap);
       pthread_mutex_unlock(&mysql_mutex);
       free(myswap);
@@ -233,7 +234,14 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
 
       #endif
 
-      stat = socket_send(gd.ms.sk[pd->rec.fdno], "200 OK\n", gd.bs.life_int);
+
+      sostat = socket_send(gd.ms.sk[pd->rec.fdno], "200 OK\n", gd.bs.life_int);
+
+      if(sostat < 0){
+         stat = 0;
+         printf("neg_logi(): 認証したがSOCKETに異常 stat = %d\n", stat);
+         }
+
       } 
    else {
       fprintf(stderr,"neg_logi(): This account is used.\n");
