@@ -46,6 +46,10 @@ gd.md.in_mailonoff = 1;
 gd.md.ch_MailCc = safe_memcpy(gd.md.ch_MailCc,"NOT",IP_LEN);
 gd.bs.life_int = 10;
 gd.bs.life_los = 5;
+#ifdef SIGNATURE_MODE
+gd.sig.sig_filename = safe_memcpy(gd.sig.sig_filename, "/tmp/sig.list", LOGPATH_LEN);
+gd.sig.sig_interval = 300;
+#endif
 
 if(gd.cron_onoff < 0){ gd.cron_onoff = 0; }
 
