@@ -61,7 +61,7 @@ NULL!=strstr(pd->getdata," DATA: ") && NULL!=strstr(pd->getdata, " :: ")){
                   case 0 : ret = socket_send(gd.ms.sk[pd->rec.fdno], 
                                   "500 NG Illegal method.\n", (pd->life.life_int + pd->life.life_los + 15));
                        #ifdef LOG_OUT
-                       pthread_mutex_lock(&con_mutex);
+                       safe_pthread_mutex_lock(&con_mutex);
                        log_out(gd.fp.con_fd, pd->rec.user,
                          "<Not>", "Illegal method.", " ", gd.ms.inip_addr[pd->rec.fdno]);
                        pthread_mutex_unlock(&con_mutex);
@@ -87,7 +87,7 @@ NULL!=strstr(pd->getdata," DATA: ") && NULL!=strstr(pd->getdata, " :: ")){
                   default : ret = socket_send(gd.ms.sk[pd->rec.fdno],
                                    "500 NG Illegal method.\n", (pd->life.life_int + pd->life.life_los + 15));
                        #ifdef LOG_OUT
-                       pthread_mutex_lock(&con_mutex);
+                       safe_pthread_mutex_lock(&con_mutex);
                        log_out(gd.fp.con_fd, pd->rec.user,
                          "<Not>", "Illegal method.", " ", gd.ms.inip_addr[pd->rec.fdno]);
                        pthread_mutex_unlock(&con_mutex);
@@ -104,7 +104,7 @@ NULL!=strstr(pd->getdata," DATA: ") && NULL!=strstr(pd->getdata, " :: ")){
 else {
    ret = socket_send(gd.ms.sk[pd->rec.fdno], "500 NG No data!\n", (pd->life.life_int + pd->life.life_los + 15));
    #ifdef LOG_OUT
-   pthread_mutex_lock(&con_mutex);
+   safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user,
     "<Not>", "prease check send data.", " ", gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
