@@ -8,6 +8,10 @@
      #include "version.h"
   #endif
 
+  #ifndef _NETDB_H
+    #include<netdb.h>
+  #endif
+
   #define CL_VAR "zither-"VERSION
 
   #define BUF_LEN 256
@@ -83,6 +87,8 @@
 
   pthread_mutex_t err_mutex;
   pthread_mutex_t con_mutex;
+  pthread_mutex_t stat_mutex;
+  pthread_mutex_t sig_mutex;
 
   #ifdef POSTGRES_IN 
     pthread_mutex_t pg_mutex;
@@ -92,6 +98,7 @@
     pthread_mutex_t mysql_mutex;
   #endif
 
+  #define SOCKMAX 128
 
   typedef struct mail_data mail_data_t;
 
@@ -197,14 +204,29 @@
 
     struct {
        int max_count;
-       long int fdno;
+//     long int fdno;
        int * fdstat;
        int * sk;
        int ls;
        char * ip_addr;
        int port;
        struct sockaddr_in my_addr;
-       unsigned char ** inip_addr;
+       char ** inip_addr;
+
+       // v6 開発の為に追加
+       struct sockaddr_storage from;
+       struct sockaddr_in * sin;
+       struct sockaddr_in6 * sin6;
+       int fromlen;
+
+       int smax;
+//     long int fdcount;
+//     int pt;
+       fd_set rfd0;
+       fd_set rfd;
+       char * chport;
+       struct addrinfo hints;
+       int ss[SOCKMAX + 10];
        }ms; /* my_sock */
     struct {
        char * conf_path;            /* read onlly */
